@@ -120,6 +120,7 @@ private Q_SLOTS:
     void terminalColumnsEntryChanged(int);
     void terminalRowsEntryChanged(int);
     void showTerminalSizeHint(bool);
+    void setDimWhenInactive(bool);
     void showEnvironmentEditor();
     void silenceSecondsChanged(int);
 
@@ -192,6 +193,7 @@ private Q_SLOTS:
     void lineSpacingChanged(int);
     void toggleBlinkingCursor(bool);
     void updateUrlHintsModifier(bool);
+    void toggleReverseUrlHints(bool);
 
     void setCursorShape(int);
     void autoCursorColor();
@@ -227,8 +229,8 @@ private:
     KeyboardTranslatorManager *_keyManager = KeyboardTranslatorManager::instance();
 
     // Updates the key bindings list widget on the Keyboard tab and selects
-    // @p selectTranslatorName
-    void updateKeyBindingsList(const QString &selectTranslatorName = QString());
+    // @p selectKeyBindingsName
+    void updateKeyBindingsList(const QString &selectKeyBindingsName = QString());
     void updateKeyBindingsButtons();
     void showKeyBindingEditor(bool isNewTranslator);
 
