@@ -39,8 +39,8 @@
 
 using namespace Konsole;
 
-IncrementalSearchBar::IncrementalSearchBar(QWidget *aParent) :
-    QWidget(aParent),
+IncrementalSearchBar::IncrementalSearchBar(QWidget *parent) :
+    QWidget(parent),
     _searchEdit(nullptr),
     _caseSensitive(nullptr),
     _regExpression(nullptr),
@@ -207,10 +207,11 @@ void IncrementalSearchBar::setSearchText(const QString &text)
 
 bool IncrementalSearchBar::eventFilter(QObject *watched, QEvent *event)
 {
-    if ((event->type() != QEvent::KeyPress) || watched != _searchEdit)
+    if ((event->type() != QEvent::KeyPress) || watched != _searchEdit) {
         return QWidget::eventFilter(watched, event);
+    }
 
-    QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+    auto *keyEvent = static_cast<QKeyEvent *>(event);
     if (keyEvent->key() == Qt::Key_Escape) {
         emit closeClicked();
         return true;
