@@ -30,7 +30,7 @@
 #include <unistd.h>
 #include <pwd.h>
 #include <sys/param.h>
-#include <errno.h>
+#include <cerrno>
 
 // Qt
 #include <QDir>
@@ -373,8 +373,9 @@ void UnixProcessInfo::readProcessInfo(int pid)
             //Append process name along with sudo
             const QVector<QString> &args = arguments(&ok);
 
-            if (ok && args.size() > 1)
+            if (ok && args.size() > 1) {
                 setName(processNameString + QStringLiteral(" ") + args[1]);
+            }
         }
     }
 }
@@ -429,7 +430,7 @@ protected:
         char path_buffer[MAXPATHLEN + 1];
         path_buffer[MAXPATHLEN] = 0;
         QByteArray procCwd = QFile::encodeName(QStringLiteral("/proc/%1/cwd").arg(pid));
-        const int length = static_cast<int>(readlink(procCwd.constData(), path_buffer, MAXPATHLEN));
+        const auto length = static_cast<int>(readlink(procCwd.constData(), path_buffer, MAXPATHLEN));
         if (length == -1) {
             setError(UnknownError);
             return false;
@@ -498,7 +499,7 @@ private:
         // read process status file ( /proc/<pid/stat )
         //
         // the expected file format is a list of fields separated by spaces, using
-        // parenthesies to escape fields such as the process name which may itself contain
+        // parentheses to escape fields such as the process name which may itself contain
         // spaces:
         //
         // FIELD FIELD (FIELD WITH SPACES) FIELD FIELD
@@ -622,7 +623,7 @@ protected:
         return true;
 #else
         int numrecords;
-        struct kinfo_file *info = 0;
+        struct kinfo_file *info = nullptr;
 
         info = kinfo_getfile(pid, &numrecords);
 
