@@ -380,6 +380,7 @@ public:
     // Returns true if the current screen is the secondary/alternate one
     // or false if it's the primary/normal buffer
     bool isPrimaryScreen();
+    void tabTitleSetByUser(bool set);
 
 public Q_SLOTS:
 
@@ -590,7 +591,7 @@ public Q_SLOTS:
     /**
      * Sets the current session's profile
      */
-    Q_SCRIPTABLE void setProfile(const QString &profile);
+    Q_SCRIPTABLE void setProfile(const QString &profileName);
 
 Q_SIGNALS:
 
@@ -707,11 +708,6 @@ Q_SIGNALS:
      */
     void getBackgroundColor();
 
-    /**
-     * Relays the tabRenamedByUser signal from SessionController
-     */
-    void tabRenamedByUser(bool renamed) const;
-
 private Q_SLOTS:
     void done(int, QProcess::ExitStatus);
 
@@ -742,8 +738,6 @@ private Q_SLOTS:
 
     void sessionAttributeRequest(int id);
 
-    void tabTitleSetByUser(bool set);
-
 private:
     Q_DISABLE_COPY(Session)
 
